@@ -6,7 +6,7 @@ PAMclustering=PAMClustering=function(DataOrDistances,ClusterNo,PlotIt=FALSE,Stan
   if(Standardization==0) Standardization=FALSE
   #author: MT, 04/2018
   requireNamespace('cluster')
-      if (isSymmetric(DataOrDistances)) {
+      if (isSymmetric(unname(DataOrDistances))) {
       Input = as.dist(DataOrDistances)
       requireNamespace('ProjectionBasedClustering')
       DataPoints=ProjectionBasedClustering::MDS(DataOrDistances,OutputDimension = 3)$ProjectedPoints
